@@ -18,22 +18,20 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
 """ Module that provides the Cosimulation class """
-from __future__ import absolute_import
-
-
+import sys
 import os
-import shlex
+#import shlex
 import subprocess
+from os import set_inheritable
 
 from myhdl._intbv import intbv
 from myhdl import _simulator, CosimulationError
-from myhdl._compat import PY2, string_types, to_bytes, to_str
 
 _MAXLINE = 4096
 
+
 class _error:
     pass
-_error.MultipleCosim = "Only a single cosimulator allowed"
 _error.DuplicateSigNames = "Duplicate signal name in myhdl vpi call"
 _error.SigNotFound = "Signal not found in Cosimulation arguments"
 _error.TimeZero = "myhdl vpi call when not at time 0"
@@ -41,25 +39,26 @@ _error.NoCommunication = "No signals communicating to myhdl"
 _error.SimulationEnd = "Premature simulation end"
 _error.OSError = "OSError"
 
+
 class Cosimulation(object):
 
     """ Cosimulation class. """
 
     def __init__(self, exe="", **kwargs):
-        
         """ Construct a cosimulation object. """
-        
-        if _simulator._cosim:
-            raise CosimulationError(_error.MultipleCosim)
-        _simulator._cosim = 1
-        
-        self._rt, self._wt = rt, wt = os.pipe()
-        self._rf, self._wf = rf, wf = os.pipe()
+        rt, wt = os.pipe()
+        rf, wf = os.pipe()
 
-        # New pipes are not inheritable by default since py 3.4
-        if not PY2:
-            for p in rt, wt, rf, wf:
-                os.set_inheritable(p, True)
+        # Disable inheritance for ends that we don't want the child to have
+        set_inheritable(rt, False)
+        set_inheritable(wf, False)
+
+        # Enable inheritance for child ends
+        set_inheritable(wt, True)
+        set_inheritable(rf, True)
+
+        self._rt = rt
+        self._wf = wf
 
         self._fromSignames = fromSignames = []
         self._fromSizes = fromSizes = []
@@ -71,20 +70,25 @@ class Cosimulation(object):
         self._hasChange = 0
         self._getMode = 1
 
-        def close_rt_wf():
-            os.close(rt)
-            os.close(wf)
-
         env = os.environ.copy()
-        env['MYHDL_TO_PIPE'] = str(wt)
-        env['MYHDL_FROM_PIPE'] = str(rf)
 
-        if isinstance(exe, string_types):
-            exe = shlex.split(exe)
-            
+        # In Windows the FDs aren't inheritable when using Popen,
+        # only the HANDLEs are
+        if sys.platform != "win32":
+            env['MYHDL_TO_PIPE'] = str(wt)
+            env['MYHDL_FROM_PIPE'] = str(rf)
+        else:
+            import msvcrt
+            env['MYHDL_TO_PIPE'] = str(msvcrt.get_osfhandle(wt))
+            env['MYHDL_FROM_PIPE'] = str(msvcrt.get_osfhandle(rf))
+
+        if isinstance(exe, str):
+#             exe = shlex.split(exe)
+            exe = exe.split(' ')
+
+
         try:
-            sp = subprocess.Popen(exe, env=env, close_fds=False,
-                                  preexec_fn=close_rt_wf)
+            sp = subprocess.Popen(exe, env=env, close_fds=False)
         except OSError as e:
             raise CosimulationError(_error.OSError, str(e))
 
@@ -93,14 +97,14 @@ class Cosimulation(object):
         os.close(wt)
         os.close(rf)
         while 1:
-            s = to_str(os.read(rt, _MAXLINE))
+            s = os.read(rt, _MAXLINE).decode()
             if not s:
                 raise CosimulationError(_error.SimulationEnd)
             e = s.split()
             if e[0] == "FROM":
                 if int(e[1]) != 0:
                     raise CosimulationError(_error.TimeZero, "$from_myhdl")
-                for i in range(2, len(e)-1, 2):
+                for i in range(2, len(e) - 1, 2):
                     n = e[i]
                     if n in fromSignames:
                         raise CosimulationError(_error.DuplicateSigNames, n)
@@ -108,12 +112,12 @@ class Cosimulation(object):
                         raise CosimulationError(_error.SigNotFound, n)
                     fromSignames.append(n)
                     fromSigs.append(kwargs[n])
-                    fromSizes.append(int(e[i+1]))
+                    fromSizes.append(int(e[i + 1]))
                 os.write(wf, b"OK")
             elif e[0] == "TO":
                 if int(e[1]) != 0:
                     raise CosimulationError(_error.TimeZero, "$to_myhdl")
-                for i in range(2, len(e)-1, 2):
+                for i in range(2, len(e) - 1, 2):
                     n = e[i]
                     if n in toSignames:
                         raise CosimulationError(_error.DuplicateSigNames, n)
@@ -122,7 +126,7 @@ class Cosimulation(object):
                     toSignames.append(n)
                     toSigs.append(kwargs[n])
                     toSigDict[n] = kwargs[n]
-                    toSizes.append(int(e[i+1]))
+                    toSizes.append(int(e[i + 1]))
                 os.write(wf, b"OK")
             elif e[0] == "START":
                 if not toSignames:
@@ -135,12 +139,12 @@ class Cosimulation(object):
     def _get(self):
         if not self._getMode:
             return
-        buf = to_str(os.read(self._rt, _MAXLINE))
+        buf = os.read(self._rt, _MAXLINE).decode()
         if not buf:
             raise CosimulationError(_error.SimulationEnd)
         e = buf.split()
         for i in range(1, len(e), 2):
-            s, v = self._toSigDict[e[i]], e[i+1]
+            s, v = self._toSigDict[e[i]], e[i + 1]
             if v in 'zZ':
                 next = None
             elif v in 'xX':
@@ -149,19 +153,19 @@ class Cosimulation(object):
                 try:
                     next = int(v, 16)
                     if s._nrbits and s._min is not None and s._min < 0:
-                        if next >= (1 << (s._nrbits-1)):
+                        if next >= (1 << (s._nrbits - 1)):
                             next |= (-1 << s._nrbits)
                 except ValueError:
                     next = intbv(0)
             s.next = next
-                 
+
         self._getMode = 0
 
     def _put(self, time):
         buflist = []
         buf = repr(time)
         if buf[-1] == 'L':
-            buf = buf[:-1] # strip trailing L
+            buf = buf[:-1]  # strip trailing L
         buflist.append(buf)
         if self._hasChange:
             self._hasChange = 0
@@ -172,9 +176,9 @@ class Cosimulation(object):
                     v += (1 << s._nrbits)
                 buf = hex(v)[2:]
                 if buf[-1] == 'L':
-                    buf = buf[:-1] # strip trailing L
+                    buf = buf[:-1]  # strip trailing L
                 buflist.append(buf)
-        os.write(self._wf, to_bytes(" ".join(buflist)))
+        os.write(self._wf, (" ".join(buflist)).encode())
         self._getMode = 1
 
     def _waiter(self):
@@ -182,7 +186,3 @@ class Cosimulation(object):
         while 1:
             yield sigs
             self._hasChange = 1
-            
-    def __del__(self):
-        """ Clear flag when this object destroyed - to suite unittest. """
-        _simulator._cosim = 0
