@@ -3,8 +3,9 @@ from myhdl import *
 from arith_utils import BEHAVIOR
 from PrefixAnd import PrefixAnd
 
+
 def LeadZeroDet(width, speed, A, Z, architecture=BEHAVIOR):
-    
+
     """ Set output bit to 1 at first non-zero MSB bit in input
 
     width -- bit width
@@ -32,24 +33,22 @@ def LeadZeroDet(width, speed, A, Z, architecture=BEHAVIOR):
         PIT = Signal(intbv(0))
         POT = Signal(intbv(0))
         prefix = PrefixAnd(width, speed, PIT, POT)
+
         @instance
-        def logic():
+        def comb():
             while 1:
                 yield PI, POT, PO, A
                 PI.next = ~A
                 for i in downrange(width):
-                    PIT.next[i] = PI[width-i-1]
-                    PO.next[i] = POT[width-i-1]
-                Z.next[width-1] = A[width-1]
-                Z.next[width-1:] = PO[width:1] & A[width-1:]
-        return [prefix, logic]
+                    PIT.next[i] = PI[width - i - 1]
+                    PO.next[i] = POT[width - i - 1]
+                Z.next[width - 1] = A[width - 1]
+                Z.next[width - 1:] = PO[width:1] & A[width - 1:]
+
+        return [prefix, comb]
 
     if architecture == BEHAVIOR:
         return Behavioral
     else:
         return Structural()
-                
-                    
-
-        
 
