@@ -1,24 +1,26 @@
 import myhdl
 from myhdl import *
 
+
 def dffa(q, d, clk, rst):
 
     @always(clk.posedge, rst.negedge)
-    def logic():
+    def synch():
         if rst == 0:
             q.next = 0
         else:
             q.next = d
 
-    return logic
+    return synch
 
 
 from random import randrange
 
+
 def test_dffa():
-    
+
     q, d, clk, rst = [Signal(bool(0)) for i in range(4)]
-    
+
     dffa_inst = dffa(q, d, clk, rst)
 
     @always(delay(10))
@@ -41,21 +43,22 @@ def test_dffa():
 
     return dffa_inst, clkgen, stimulus, rstgen
 
+
 def simulate(timesteps):
     tb = traceSignals(test_dffa)
     sim = Simulation(tb)
     sim.run(timesteps)
     sim.quit()
 
+
 simulate(20000)
 
+
 def convert():
     q, d, clk, rst = [Signal(bool(0)) for i in range(4)]
     toVerilog(dffa, q, d, clk, rst)
     conversion.analyze(dffa, q, d, clk, rst)
- 
+
+
 convert()
- 
 
-
-    
