@@ -4,8 +4,9 @@ from myhdl import *
 ACTIVE = 0
 DirType = enum('RIGHT', 'LEFT')
 
+
 def jc2(goLeft, goRight, stop, clk, q):
-    
+
     """ A bi-directional 4-bit Johnson counter with stop control.
 
     I/O pins:
@@ -33,7 +34,7 @@ def jc2(goLeft, goRight, stop, clk, q):
     run = Signal(False)
 
     @always(clk.posedge)
-    def logic():
+    def synch():
         # direction
         if goRight == ACTIVE:
             dir.next = DirType.RIGHT
@@ -53,4 +54,4 @@ def jc2(goLeft, goRight, stop, clk, q):
                 q.next[3:] = q[4:1]
                 q.next[3] = not q[0]
 
-    return logic
+    return synch
