@@ -3,17 +3,18 @@ from myhdl import *
 
 from random import randrange
 
+
 def arbiter(grant_vector, request_vector):
-    
+
     @always_comb
-    def logic():
+    def comb():
         grant_vector.next = 0
         for i in range(len(request_vector)):
             if request_vector[i] == 1:
                 grant_vector.next[i] = 1
                 break
 
-    return logic
+    return comb
 
 
 def check():
@@ -38,20 +39,13 @@ def check():
             yield delay(10)
             if 1 in request_list:
                 assert grant_list.index(1) == request_list.index(1)
-                assert grant_list.count(0) == M-1
-                #print bin(grant_vector, 8), bin(request_vector, 8)
+                assert grant_list.count(0) == M - 1
+                # print bin(grant_vector, 8), bin(request_vector, 8)
         raise StopSimulation()
 
     return arb, stimulus
-        
-        
+
 
 sim = Simulation(check())
 sim.run()
 
-                 
-
-
-
-
-    
