@@ -1,5 +1,6 @@
 from myhdl import always_comb
 
+
 def bin2gray(B, G, width):
     """ Gray encoder.
 
@@ -9,8 +10,8 @@ def bin2gray(B, G, width):
     """
 
     @always_comb
-    def logic():
+    def comb():
         for i in range(width):
-            G.next[i] = B[i+1] ^ B[i]
+            G.next[i] = B[i + 1] ^ B[i]
 
-    return logic
+    return comb
